aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEli Schwartz <eschwartz@archlinux.org>2023-01-08 15:35:22 -0500
committerNirbheek Chauhan <nirbheek@centricular.com>2023-02-06 23:37:24 +0530
commitacf85bc8141395d456d90f04b303835c72c3dbdf (patch)
tree23bc1999fdec8b08ab1d99d6ca7fbdd44b026fc4
parentae83c72b705ee1d1cdfd97936ca4de3adcf22eb3 (diff)
downloadmeson-acf85bc8141395d456d90f04b303835c72c3dbdf.zip
meson-acf85bc8141395d456d90f04b303835c72c3dbdf.tar.gz
meson-acf85bc8141395d456d90f04b303835c72c3dbdf.tar.bz2
avoid detecting masm as a MSVC-like compiler for detecting showincludes
It's msvc-like but, just like Intel Fortran, doesn't support this argument.
-rw-r--r--mesonbuild/backend/ninjabackend.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/mesonbuild/backend/ninjabackend.py b/mesonbuild/backend/ninjabackend.py
index 3e3c770..093e2ef 100644
--- a/mesonbuild/backend/ninjabackend.py
+++ b/mesonbuild/backend/ninjabackend.py
@@ -512,8 +512,8 @@ class NinjaBackend(backends.Backend):
for compiler in self.environment.coredata.compilers.host.values():
# Have to detect the dependency format
- # IFort on windows is MSVC like, but doesn't have /showincludes
- if compiler.language == 'fortran':
+ # IFort / masm on windows is MSVC like, but doesn't have /showincludes
+ if compiler.language in {'fortran', 'masm'}:
continue
if compiler.id == 'pgi' and mesonlib.is_windows():
# for the purpose of this function, PGI doesn't act enough like MSVC